import React from 'react'
import Form from './Form'

const instructions = [
  {
    title: "Provide more information about your property needs",
    image: "property"
  },
  {
    title: "Shortlist more land for site visits & evaluation",
    image: "country"
  },
  {
    title: "Rate your experience with us and give feedback",
    image: "rating"
  },
  {
    title: "View assigned sales expert's export profile & request for change if required",
    image: "skill"
  },
  {
    title: "Manage your meetings/site visits schedule",
    image: "room"
  }
]

const Page = () => {
  return (
    <div className='relative min-h-screen'> 
      {/* Background Image */}
      <img
        src="/broker-bg.png"
        alt="background"
        className='w-full h-full min-h-screen object-cover absolute top-0 left-0'
      />
      {/* Content Container */}
      <div className="relative z-10 w-full min-h-screen">
        <div className="container mx-auto px-4 py-8 md:py-12">
          <div className="flex flex-col lg:flex-row gap-12 lg:gap-16 items-start">
            {/* Instructions Section */}
            <div className="flex flex-col gap-4 text-white font-medium lg:max-w-xl">
              <p className='text-xl md:text-2xl mb-4'>
                Take control of the service experience during your land search & Ownership journey
              </p>
              <div className="space-y-4">
                {instructions.map(item => (
                  <div
                    className='flex items-center gap-4 bg-black/20 backdrop-blur-sm p-3 rounded-lg transition-transform hover:translate-x-2'
                    key={item.image}
                  >
                    <img
                      src={`/icons/${item.image}.png`}
                      alt=""
                      className='w-6 h-6 sm:w-7 sm:h-7 object-contain'
                    />
                    <p className='text-sm sm:text-base'>{item.title}</p>
                  </div>
                ))}
              </div>
            </div>
            {/* Form Section */}
            <div className="lg:flex-1">
              <Form />
            </div>
          </div>
        </div>
      </div>
    </div>
  )
}

export default Page